@@ -111,16 +111,26 @@ class Listing(Float):
     if isinstance(container, StringContainer):
       return self.modifystring(container)
     if isinstance(container, StandardLayout):
-      return self.modifystring(container)
+      return self.modifylayout(container)
     Trace.error('Unexpected container ' + container.__class__.__name__ +
         ' in listing')
     return []
 
   def modifystring(self, string):
     "Modify a listing string"
-    if len(string.contents) == 0:
-      string.contents = [Constant(u'​')]
-    contents = [string, Constant('\n')]
+    if string.string == '':
+      string.string = u'​'
+    return self.modifycontainer(string)
+
+  def modifylayout(self, layout):
+    "Modify a standard layout"
+    if len(layout.contents) == 0:
+      layout.contents = [Constant(u'​')]
+    return self.modifycontainer(layout)
+
+  def modifycontainer(self, container):
+    "Modify a listing container"
+    contents = [container, Constant('\n')]
     if self.numbered:
       self.counter += 1
       tag = 'span class="number-' + self.numbered + '"'
@@ -191,5 +201,5 @@ class PostListing(PostFloat):
 
   processedclass = Listing
 
-Postprocessor.contents += [PostFloat, PostWrap, PostListing]
+Postprocessor.stages += [PostFloat, PostWrap, PostListing]
 
