@@ -31,15 +31,6 @@ from gen.container import *
 class QuoteContainer(Container):
   "A container for a pretty quote"
 
-  outputs = {
-      'eld':u'“', 'erd':u'”', 'els':u'‘', 'ers':u'’',
-      'sld':u'”', 'srd':u'”',
-      'gld':u'„', 'grd':u'“', 'gls':u'‚', 'grs':u'‘',
-      'pld':u'„', 'prd':u'”', 'pls':u'‚', 'prs':u'’',
-      'fld':u'«', 'frd':u'»', 'fls':u'‹', 'frs':u'›',
-      'ald':u'»', 'ard':u'«', 'als':u'›', 'ars':u'‹'
-      }
-
   def __init__(self):
     self.parser = BoundedParser()
     self.output = FixedOutput()
@@ -47,11 +38,11 @@ class QuoteContainer(Container):
   def process(self):
     "Process contents"
     self.type = self.header[2]
-    if not self.type in QuoteContainer.outputs:
+    if not self.type in StyleConfig.quotes:
       Trace.error('Quote type ' + self.type + ' not found')
-      self.html = '"'
+      self.html = ['"']
       return
-    self.html = QuoteContainer.outputs[self.type]
+    self.html = [StyleConfig.quotes[self.type]]
 
 class LyxLine(Container):
   "A Lyx line"
@@ -72,15 +63,13 @@ class EmphaticText(TaggedText):
 class ShapedText(TaggedText):
   "Text shaped (italic, slanted)"
 
-  tags = {'slanted':'i', 'italic':'i', 'smallcaps':'span class="versalitas"'}
-
   def process(self):
     self.type = self.header[1]
-    if not self.type in ShapedText.tags:
+    if not self.type in TagConfig.shaped:
       Trace.error('Unrecognized shape ' + self.header[1])
       self.output.tag = 'span'
       return
-    self.output.tag = ShapedText.tags[self.type]
+    self.output.tag = TagConfig.shaped[self.type]
 
 class VersalitasText(TaggedText):
   "Text in versalitas"
@@ -111,12 +100,14 @@ class BoldText(TaggedText):
 class TextFamily(TaggedText):
   "A bit of text from a different family"
 
-  typetags = { 'typewriter':'tt', 'sans':'span class="sans"' }
-
   def process(self):
     "Parse the type of family"
     self.type = self.header[1]
-    self.output.tag = TextFamily.typetags[self.type]
+    if not self.type in TagConfig.family:
+      Trace.error('Unrecognized family ' + type)
+      self.output.tag = 'span'
+      return
+    self.output.tag = TagConfig.family[self.type]
 
 class Hfill(TaggedText):
   "Horizontall fill"
@@ -127,16 +118,14 @@ class Hfill(TaggedText):
 class BarredText(TaggedText):
   "Text with a bar somewhere"
 
-  typetags = { 'under':'u' }
-
   def process(self):
     "Parse the type of bar"
     self.type = self.header[1]
-    if not self.type in BarredText.typetags:
+    if not self.type in TagConfig.barred:
       Trace.error('Unknown bar type ' + self.type)
       self.output.tag = 'span'
       return
-    self.output.tag = BarredText.typetags[self.type]
+    self.output.tag = TagConfig.barred[self.type]
 
 class LangLine(Container):
   "A line with language information"
@@ -148,3 +137,19 @@ class LangLine(Container):
   def process(self):
     self.lang = self.header[1]
 
+class Space(Container):
+  "A space of several types"
+
+  def __init__(self):
+    self.parser = InsetParser()
+    self.output = FixedOutput()
+  
+  def process(self):
+    self.type = self.header[2]
+    if self.type not in StyleConfig.spaces:
+      Trace.error('Unknown space type ' + self.type)
+      self.html = [' ']
+      return
+    self.html = [StyleConfig.spaces[self.type]]
+
+
