@@ -95,49 +95,91 @@ class Postprocessor(object):
   "Postprocess a container keeping some context"
 
   stages = [PostLayout, PostStandard]
-  unconditional = []
-  contents = []
 
   def __init__(self):
-    self.stages = self.instantiate(Postprocessor.stages)
-    self.stagedict = dict([(x.processedclass, x) for x in self.stages])
-    self.unconditional = self.instantiate(Postprocessor.unconditional)
-    self.contents = self.instantiate(Postprocessor.contents)
-    self.contentsdict = dict([(x.processedclass, x) for x in self.contents])
+    self.stages = StageDict(Postprocessor.stages, self)
+    self.hooks = []
     self.last = None
 
   def postprocess(self, container):
     "Postprocess the root container and its contents"
-    container = self.postprocessroot(container)
-    self.postprocesscontents(container.contents)
-    return container
+    self.postrecursive(container)
+    result = self.postcurrent(container)
+    result = self.posthooks(container, result)
+    self.last = container
+    return result
 
-  def postprocessroot(self, original):
-    "Postprocess an element taking into account the last one"
-    element = original
-    if element.__class__ in self.stagedict:
-      stage = self.stagedict[element.__class__]
-      element = stage.postprocess(element, self.last)
-    for stage in self.unconditional:
-      element = stage.postprocess(element, self.last)
-    self.last = original
-    return element
-
-  def postprocesscontents(self, contents):
-    "Postprocess the container contents"
-    last = None
+  def postrecursive(self, container):
+    "Postprocess the container contents recursively"
+    if not hasattr(container, 'contents'):
+      return
+    contents = container.contents
+    if len(contents) == 0:
+      return
+    postprocessor = Postprocessor()
     for index, element in enumerate(contents):
       if isinstance(element, Container):
-        self.postprocesscontents(element.contents)
-      if element.__class__ in self.contentsdict:
-        stage = self.contentsdict[element.__class__]
-        contents[index] = stage.postprocess(element, last)
-      last = contents[index]
+        contents[index] = postprocessor.postprocess(element)
+    postlast = postprocessor.postprocess(None)
+    if postlast:
+      contents.append(postlast)
 
-  def instantiate(self, classes):
+  def postcurrent(self, element):
+    "Postprocess the current element taking into account the last one"
+    stage = self.stages.getstage(element)
+    if not stage:
+      return element
+    return stage.postprocess(element, self.last)
+
+  def addhook(self, hook):
+    "Add a postprocessing hook; only one of each type allowed."
+    for element in self.hooks:
+      if isinstance(element, hook.__class__):
+        return
+    self.hooks.append(hook)
+    hook.postprocessor = self
+
+  def posthooks(self, element, result):
+    "Postprocess the current element using the hooks."
+    "The element is used to see if the hook applies, but the previous"
+    "result is actually used in postprocessing."
+    for hook in self.hooks:
+      if hook.applies(element, self.last):
+        result = hook.postprocess(result, self.last)
+    return result
+
+class StageDict(object):
+  "A dictionary of stages corresponding to classes"
+
+  def __init__(self, classes, postprocessor):
+    "Instantiate an element from each class and store as a dictionary"
+    instances = self.instantiate(classes, postprocessor)
+    self.stagedict = dict([(x.processedclass, x) for x in instances])
+
+  def instantiate(self, classes, postprocessor):
     "Instantiate an element from each class"
-    list = [x.__new__(x) for x in classes]
-    for element in list:
+    stages = [x.__new__(x) for x in classes]
+    for element in stages:
       element.__init__()
-    return list
+      element.postprocessor = postprocessor
+    return stages
+
+  def getstage(self, element):
+    "Get the stage for a given element, if the type is in the dict"
+    if not element.__class__ in self.stagedict:
+      return None
+    return self.stagedict[element.__class__]
+
+class PostHook(object):
+  "A postprocessing hook inserted by another postprocessing stage."
+  "It can only add an element, not modify an existing one."
+  "Only a hook of a given class is allowed."
+
+  def applies(self, element, last):
+    "Decide if the hook applies or not"
+    Trace.error("applies() in PostHook")
+
+  def postprocess(self, element, last):
+    "Get the result of postprocessing"
+    Trace.error("getresult() in PostHook")
 
